/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlUnop.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvSignalLine.h"
#include "HvSignalBiquad.h"
#include "HvControlSystem.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_EsGliujI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bJiKbstv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BIplkXEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_csXr68E4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YP8gU2R7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XYLMVRit_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8Vd9WG7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_T79W2wKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RVSmOLvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rs3vzxg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E1epaEA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iJhgwzGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g5cgkL4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vLSQNtpb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yj3oyMvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uGOocB9s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4qQhQj7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHtsCbvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zjkJuSFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1I4wBptu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pDexHgZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jixofFTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z5CGb9Lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3SmybP5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KD5gzBaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aULe4Ul7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UQ52zhH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fLK5AOGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z4EyZ91I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xn35SpdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EcZmCWpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N5oUqb6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2U7qzEDB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LSWwkTPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k1UF8G6f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cU7sOGx7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zwvsQbFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XqzK0w6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rkRpKW5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ac2uocE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n3NQlr13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ljg2dy5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SlueqXoF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IRJMpD0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RoPNrkeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z2eFiXdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ct9P5a61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ypgjzRA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GvGzdFQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVfiLBkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CfIZMLT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y1nnJvqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uOWds7vi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uxYAT05T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3vKOD2iR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oudxjEzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KNCkbcPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DrrucpRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r8HV9f3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l03jzvAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i2Vw8OJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PHhDtBLd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g385R5W0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GH7chaYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zpM5oCNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jOjIBoo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JY8EqUL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hU5JTM3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ZbmrZxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9l0vFber_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hnrK1YHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bdv4qGsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_63ranQsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YF44xWEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ImA6N8N5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rcpzkupx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZggPZmM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wfIl1Fg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RUEm8HeQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jTmCOrz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YeAcDU0F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Ho1BHrI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wlo5Jh2s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8SzcP5c3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2cE6aUHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JLmdstOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_grbaLwVd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hHgy7qZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jTs5aq5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iLrpeiXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HPVjGA81_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_w6lZni0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6MX8qRbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_O4WaHiJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tCyHfvPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dilMSleS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zqHyGHfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G9IiNlhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vyjvC7x8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sIsnBiuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_moEP29Y1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Z8TbUMZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qcm48CVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fEayaJ1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pYNS7L4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_otP7W22g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PhFCCROj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MPooXx3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_l9mAdJyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kOht25DF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dub16NsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AOF0CYv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5qziJcvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a5dWdj0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B0HTVHvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHaxP6TY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TdurPOYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rVbYRZH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBK8phvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NqJCMKOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RvaF2k6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7mqmn5vN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sGPMSFrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ht0TDCuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RTpqAJTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_idvyDsbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZG3m1sYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QLIN71bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UMst69hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gRxncBWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FaMe3Y7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x5ZRmQW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N6eUXcTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_00v76p5n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LvGDiIkQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RK68Gk4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ddmy9uyj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zI7JY5EW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UwZ4YIot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LeATHoyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Whqj6COw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vOyzp1Gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KOytRGg0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xUKe9scy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8ObTs7at_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rbaZGjo8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b6Dnue3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TL8mOryt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vOWZV6mK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gh7mHjyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hzeal3YT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rcutM6L4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vuT5bqwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pSgF3LOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lf37bLi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DuhORFJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DwSeUiLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wDrY0ZXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QCGFxGx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nW9dg6wn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RyZsZgLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O51SMjEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ePxioA3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bs4Mt0tv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5r7hJdxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GVQQhEJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YhwP1UBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SMLMFosP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gkL89mjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9YE7vstl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ww7Cikae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D5Rwbf7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s57I4r9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QOyAL59m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Ob83CSX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YfHWqxzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7h9twssz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qhZGqDaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yyw9sKpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nhVJUY5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_otY9jRDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y2MPp9nD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Ugepb24B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KzVuaJ5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uBSRyQpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aDz9rBr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JxZcBwDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zjvwwnv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a2FIRE2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SA5DWBc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jd6mtT4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iW8aKgqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x5vwuEJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rfPcgBxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lSW6slHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5TTeWf6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WzhEty62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DNlE6RYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fu5fYt1D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iWvHnukm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rXw9hLRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N7C4yMKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pbPFpir3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ja6d5w0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hJRi6Yl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6nUa3Kei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_niJ3gNpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8DBzelOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qUPRIn3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oAPtVwNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2z2nk9fT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_45Tj8CSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ysiOL6mI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eYNFTTZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5tRNF1Wl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kXWsTA07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aJ63FSr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iMxkVPGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_duHZtftt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_btNvRMPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FETCw3hh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l8i4xRO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LLSrMk6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K91xIFaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_De7AY1J3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EjvXYTIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bVz9OEtW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_utAlwR00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mcvzJ6Lv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K5GDFJFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ntec8pNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_33kuMvZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_G83uRciu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RKe87Zlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1AkFcxia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sWDJxWjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_86nSAeDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hst8jjrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yTUgsCFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y0wkiBjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IUN9NT2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uz35pKJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IqKigllM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rzvi99ak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hqTYTv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wMWNXulG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gVmQIKyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X2OFKiXW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMsigrBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qUVbPodg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZY8SZff5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_km74I59G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lJj6TZeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4umkY34D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_drrJVNSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ovQeZiAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R6m3pRfm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0eUQv4Qs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NsSMgA91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_04BDE6mz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gu2ky7Qx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0WNgQncq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ElQAkhA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tytBvNTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Igkvl6qU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ttxiK17p_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_nNd7LIUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZLAGVN56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vnpoyFso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O3VmYZPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4UG3gKss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DYmQzSF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5y8VDx11_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bpsGkUwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pIrj3070_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j2ErBzJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aXDZ8yLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JSkGpso1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_27YJvkgN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BNvHOaI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2KZ9BeOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9QNlSVY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YXGJ06m9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tpEmeeQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o5MkH9EF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o0tlyOh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jLxehgjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sxtRSKMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KMlynTdz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NfH6EchX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dqRlqGOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zL7egbeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h4JHj7nV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GAVNrx5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KNvR3HUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bur0VQqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oj2JvtIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fAJJuk2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iJ9RGxPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_798ysmtv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CMxpG5Re_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NcPZpKMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SiUtbYu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dEFmZFWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kaIVEFOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cL55hpaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kiIaFiff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qDKpXXR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v3I13Te4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9NG0hXgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hQSPS8Jq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cSDhBRMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H3PsYCEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LgVxQb4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3MbClTos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JyVw9mrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nd4zNi0I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hGsCfQAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IDljmOVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tBR7baaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TIMpoD4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VcmqL5Fj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tNb0Iivp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y30G0XQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vAjELRbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QfNjr9Dh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWreoEss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3Z3QPkGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NrFpU0zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZkdKdSda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y7UfVA8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C7W2Gcgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v7GZOga1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bE6geKl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LZCF3WLZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pM2NsgkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gdb6QAUz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a0DvGzcA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_usE4JrlI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_z2dsOwoU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3exyqq92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_znkDZzX3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7hAkszwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VWHttao2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_z0Mwm2o9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gqY4cIii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_04mdstHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_n2JmyrMW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ZnBUfOxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EYVuXo4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1FfkNicO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YofdijpM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vQ8wblyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_okSjXXBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9fWXfhig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pAWzo1lg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CEvug11N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dCOqigdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ghaDU5Tj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0FT2DuCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IIu1c9vf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yjgVTEq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xZUuBONJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DyZNtwpL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VCthhJzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t4tNhlcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pjb3YJbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aLsUz4wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QZVPdhhV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ncB82BBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WFzz822P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NwvyeKcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vRxfcNwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G1mF7cdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nCxva97k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DDXofVmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lrn5QvoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j4CSXdCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ei4ZbXTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_juQBVugv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xUDfVJaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jvSIRPNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0SUnKlv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ueizxBQ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NEIZwwDs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lJtSPcrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5ullPkhk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OiZ4lrYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZNteDVYS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CHjkJZ21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_um2sd3P0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Mkmg1Yvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NFAnKwnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i2FZMwz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fNgxj8wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_noX9dNLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cJepDlYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AkDXwDQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uYsW2WOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AP2wre81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vE5lf2eT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sbJ5WtVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jK0wlST9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7wzqITpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LySn4APX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Je9zqf6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plP0mJHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0KzVzsiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FxsI92pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_50pTECFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xNwUtgBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iZkqZGLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8MYF87gA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ypP5Ne09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aVfdoSZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RXQSQnFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5nwpgigf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BVOUafMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_canWhiXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xr1JuR65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YAMTZxSx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAKnaITK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_otIWdudW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FqMRtYaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BlgAY3O6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jzBFIFfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TRwPgB9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vP15EBzB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eBmTx1Rg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8aQaemHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1PACE8wS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X1pRRZGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Iobg9z4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1RifQOWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qDZlWAdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Hh7PxNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_940BABzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_srpxx87d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bgVMHxDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TlnKfVQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G6a7jaII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2n9R2c5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Kg1t7SPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_c8zE0x4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_err1amxm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fjxxsrq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7lt6dfEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WxNkBKUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lUCjW63k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IdUBFyRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kyezPcXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NbTMhvWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f6tg9iAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4d55udlw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uwtvks7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BsfQRBSx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MqdKJ6ix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ou4frpqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ZpmrRBo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KAGP7O6i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h9n9m421_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cr2AsPpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SnjJpIA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s17a0MeH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yfTN2JIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6aURy5Qo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XwCnE1OU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f5XeLr2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_V840hgCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KiVtWnDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FlaYJ4Eo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PMpKurWD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LJ7jyv1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G3csHPLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJ3Q2Eal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6SGw7XDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hLHvs2XG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ziHvIVEM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HNpH2rwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MpGEQ4rr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIDNPmbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kziPUw04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_woKKPJJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pGieZkof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UP8WVXNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OkQrgSbi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BxRLR3qd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n6vxQLvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hj33HRH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bNUa8mbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3oYly2RX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zwhVIUqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VNf7hBaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_92oDiSUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QR45SC4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v9XVEjpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DsLv7c4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HvhlIeST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yxdkpxNY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_S5P1FTfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C4MywSyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xYu9c4sR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iiZhhX4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WWg2kNYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_akrPbuCH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l3Feh99a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zvyuz5xa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_krEdbSd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WXTO9lDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a4cIW8U6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mb4g1Eqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vgyDcdYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mmyR4rNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OORjgnhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zKEGsxEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4BS2ZfmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mW1DGpPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T8JvQ0hA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j0d5llXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NOdwA1o9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ShPEfRV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h3fZpP8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rttA8yEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RtNMLMcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nvUGMNR0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5m816Rf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2OE4YqYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DyH8jt41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rrKblCOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AmYOuTw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YQCwz2Fo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iAfkz08V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NnpLPykZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tc7tWLu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zLa2UOOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mg7hINB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6XSIhJjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SoUWv0n2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KZarCtHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w7H7WGaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zYENA4fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ujdOhKbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6Yag49oN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_thbPbLes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uQTRf3Zh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MceMdrfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gx3rSjrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MxGFZCJQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y9mzQqTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mGdEGZXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3xJx7aFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6P5D2JPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GeRfRBLY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CWo9ZkBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v5GxKbi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6HTpOp3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iuH080zA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KePWGtdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BaYL5FQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Eu8Yoes3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vRsCdxWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5FmsqTyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y3mlBxeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vqBETnka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jcYUxbe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_60JkJTuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p6wRPT3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kcJmjQsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bGG2tuLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nfpTs1BM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HJWVRqea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fm7zyJh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GIzjSxFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e93N5RBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MEgzHM9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LUxUMqlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WLLTvbzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9J8dxTuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IPO5pI7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4UHmekKC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JV2Tj9Hr_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_9To1tawT;
  SignalLine sLine_JaFdJuzA;
  SignalLine sLine_cQX4gkTi;
  SignalLine sLine_I3xmZLEJ;
  SignalLine sLine_hyyTcs33;
  SignalBiquad sBiquad_s_vMW7mDXX;
  SignalLine sLine_jfJXNnet;
  SignalLine sLine_SYbVdvn5;
  SignalLine sLine_gmjZZDck;
  SignalLine sLine_IZuce8UZ;
  SignalBiquad sBiquad_s_6Dcb8CgM;
  SignalLine sLine_1lYcPAhh;
  SignalLine sLine_F87Uv2ZV;
  SignalLine sLine_ZrrU4hLz;
  SignalLine sLine_DrWD2q9A;
  SignalLine sLine_TzW55BTy;
  SignalBiquad sBiquad_s_uwZmSxW2;
  SignalLine sLine_tOw7tOrl;
  SignalLine sLine_swExL2ol;
  SignalLine sLine_49kQeaM4;
  SignalLine sLine_NyTMpHVI;
  SignalLine sLine_2FsznsLH;
  SignalBiquad sBiquad_s_MPArQZDz;
  SignalLine sLine_Y6OPGTqB;
  SignalLine sLine_jiK1SahI;
  SignalLine sLine_UbZyodiV;
  SignalLine sLine_cMNSNtk7;
  SignalBiquad sBiquad_s_baHuWTjy;
  SignalLine sLine_PWGUA13Z;
  SignalLine sLine_TJSbDrXr;
  SignalLine sLine_fBMqWHs9;
  SignalLine sLine_SSmEAjxG;
  SignalLine sLine_R52th48k;
  SignalBiquad sBiquad_s_A7pP8oqh;
  ControlVar cVar_EsGliujI;
  ControlVar cVar_bJiKbstv;
  ControlVar cVar_BIplkXEe;
  ControlVar cVar_csXr68E4;
  ControlSlice cSlice_XYLMVRit;
  ControlVar cVar_8Vd9WG7G;
  ControlVar cVar_RVSmOLvU;
  ControlIf cIf_rs3vzxg9;
  ControlIf cIf_E1epaEA0;
  ControlBinop cBinop_g5cgkL4k;
  ControlBinop cBinop_vLSQNtpb;
  ControlBinop cBinop_4qQhQj7o;
  ControlBinop cBinop_OHtsCbvN;
  ControlBinop cBinop_1I4wBptu;
  ControlIf cIf_pDexHgZx;
  ControlBinop cBinop_jixofFTb;
  ControlBinop cBinop_z5CGb9Lb;
  ControlBinop cBinop_KD5gzBaz;
  ControlBinop cBinop_aULe4Ul7;
  ControlBinop cBinop_UQ52zhH0;
  ControlVar cVar_N5oUqb6w;
  ControlIf cIf_2U7qzEDB;
  ControlIf cIf_LSWwkTPq;
  ControlBinop cBinop_cU7sOGx7;
  ControlBinop cBinop_zwvsQbFj;
  ControlBinop cBinop_Ac2uocE6;
  ControlBinop cBinop_n3NQlr13;
  ControlBinop cBinop_SlueqXoF;
  ControlIf cIf_IRJMpD0v;
  ControlBinop cBinop_RoPNrkeX;
  ControlBinop cBinop_z2eFiXdn;
  ControlBinop cBinop_ypgjzRA9;
  ControlBinop cBinop_GvGzdFQE;
  ControlBinop cBinop_JVfiLBkF;
  ControlVar cVar_3vKOD2iR;
  ControlIf cIf_oudxjEzH;
  ControlIf cIf_KNCkbcPy;
  ControlBinop cBinop_r8HV9f3q;
  ControlBinop cBinop_l03jzvAR;
  ControlBinop cBinop_g385R5W0;
  ControlBinop cBinop_GH7chaYR;
  ControlBinop cBinop_jOjIBoo3;
  ControlIf cIf_JY8EqUL6;
  ControlBinop cBinop_hU5JTM3h;
  ControlBinop cBinop_9ZbmrZxp;
  ControlBinop cBinop_hnrK1YHq;
  ControlBinop cBinop_Bdv4qGsZ;
  ControlBinop cBinop_63ranQsE;
  ControlIf cIf_wfIl1Fg3;
  ControlSlice cSlice_jTmCOrz3;
  ControlVar cVar_YeAcDU0F;
  ControlSlice cSlice_8SzcP5c3;
  ControlVar cVar_2cE6aUHK;
  ControlSlice cSlice_hHgy7qZF;
  ControlVar cVar_jTs5aq5Y;
  ControlSlice cSlice_w6lZni0w;
  ControlVar cVar_6MX8qRbd;
  ControlBinop cBinop_fEayaJ1O;
  ControlBinop cBinop_otP7W22g;
  ControlBinop cBinop_PhFCCROj;
  ControlBinop cBinop_kOht25DF;
  ControlBinop cBinop_Dub16NsQ;
  ControlBinop cBinop_AOF0CYv2;
  ControlBinop cBinop_5qziJcvj;
  ControlBinop cBinop_a5dWdj0R;
  ControlVar cVar_B0HTVHvm;
  ControlBinop cBinop_OHaxP6TY;
  ControlBinop cBinop_TdurPOYd;
  ControlBinop cBinop_rVbYRZH2;
  ControlBinop cBinop_hBK8phvD;
  ControlBinop cBinop_NqJCMKOi;
  ControlBinop cBinop_RvaF2k6D;
  ControlBinop cBinop_7mqmn5vN;
  ControlBinop cBinop_ht0TDCuU;
  ControlVar cVar_RTpqAJTj;
  ControlVar cVar_idvyDsbN;
  ControlBinop cBinop_N6eUXcTW;
  ControlBinop cBinop_00v76p5n;
  ControlBinop cBinop_LvGDiIkQ;
  ControlBinop cBinop_Ddmy9uyj;
  ControlBinop cBinop_zI7JY5EW;
  ControlBinop cBinop_UwZ4YIot;
  ControlBinop cBinop_LeATHoyo;
  ControlBinop cBinop_Whqj6COw;
  ControlBinop cBinop_vOyzp1Gl;
  ControlBinop cBinop_RyZsZgLg;
  ControlBinop cBinop_ePxioA3K;
  ControlBinop cBinop_Bs4Mt0tv;
  ControlBinop cBinop_YhwP1UBn;
  ControlBinop cBinop_SMLMFosP;
  ControlBinop cBinop_gkL89mjN;
  ControlBinop cBinop_9YE7vstl;
  ControlBinop cBinop_Ww7Cikae;
  ControlBinop cBinop_D5Rwbf7b;
  ControlBinop cBinop_s57I4r9j;
  ControlBinop cBinop_2Ob83CSX;
  ControlVar cVar_YfHWqxzL;
  ControlVar cVar_7h9twssz;
  ControlVar cVar_qhZGqDaP;
  ControlBinop cBinop_uBSRyQpc;
  ControlBinop cBinop_aDz9rBr7;
  ControlBinop cBinop_JxZcBwDX;
  ControlBinop cBinop_a2FIRE2Y;
  ControlBinop cBinop_SA5DWBc1;
  ControlBinop cBinop_Jd6mtT4i;
  ControlBinop cBinop_iW8aKgqD;
  ControlBinop cBinop_x5vwuEJG;
  ControlBinop cBinop_2z2nk9fT;
  ControlBinop cBinop_ysiOL6mI;
  ControlBinop cBinop_eYNFTTZQ;
  ControlBinop cBinop_aJ63FSr1;
  ControlBinop cBinop_iMxkVPGA;
  ControlBinop cBinop_duHZtftt;
  ControlBinop cBinop_btNvRMPN;
  ControlBinop cBinop_FETCw3hh;
  ControlBinop cBinop_LLSrMk6P;
  ControlBinop cBinop_De7AY1J3;
  ControlBinop cBinop_EjvXYTIa;
  ControlBinop cBinop_utAlwR00;
  ControlBinop cBinop_mcvzJ6Lv;
  ControlBinop cBinop_K5GDFJFc;
  ControlBinop cBinop_33kuMvZZ;
  ControlVar cVar_G83uRciu;
  ControlVar cVar_RKe87Zlf;
  ControlVar cVar_1AkFcxia;
  ControlBinop cBinop_uz35pKJ5;
  ControlBinop cBinop_IqKigllM;
  ControlBinop cBinop_Rzvi99ak;
  ControlBinop cBinop_wMWNXulG;
  ControlBinop cBinop_gVmQIKyL;
  ControlBinop cBinop_X2OFKiXW;
  ControlBinop cBinop_yMsigrBN;
  ControlBinop cBinop_qUVbPodg;
  ControlBinop cBinop_ZY8SZff5;
  ControlBinop cBinop_0WNgQncq;
  ControlBinop cBinop_tytBvNTH;
  ControlBinop cBinop_Igkvl6qU;
  SignalVarf sVarf_J2aAYIhf;
  SignalVarf sVarf_wHtA0j19;
  SignalVarf sVarf_CeeyiJWK;
  ControlSlice cSlice_nNd7LIUl;
  ControlVar cVar_ZLAGVN56;
  ControlVar cVar_O3VmYZPK;
  ControlIf cIf_4UG3gKss;
  ControlIf cIf_DYmQzSF8;
  ControlBinop cBinop_bpsGkUwx;
  ControlBinop cBinop_pIrj3070;
  ControlBinop cBinop_JSkGpso1;
  ControlBinop cBinop_27YJvkgN;
  ControlBinop cBinop_2KZ9BeOM;
  ControlIf cIf_9QNlSVY7;
  ControlBinop cBinop_YXGJ06m9;
  ControlBinop cBinop_tpEmeeQ8;
  ControlBinop cBinop_o0tlyOh4;
  ControlBinop cBinop_jLxehgjE;
  ControlBinop cBinop_sxtRSKMJ;
  ControlVar cVar_h4JHj7nV;
  ControlIf cIf_GAVNrx5L;
  ControlIf cIf_KNvR3HUD;
  ControlBinop cBinop_oj2JvtIQ;
  ControlBinop cBinop_fAJJuk2S;
  ControlBinop cBinop_CMxpG5Re;
  ControlBinop cBinop_NcPZpKMr;
  ControlBinop cBinop_dEFmZFWs;
  ControlIf cIf_kaIVEFOB;
  ControlBinop cBinop_cL55hpaC;
  ControlBinop cBinop_kiIaFiff;
  ControlBinop cBinop_v3I13Te4;
  ControlBinop cBinop_9NG0hXgg;
  ControlBinop cBinop_hQSPS8Jq;
  ControlVar cVar_JyVw9mrJ;
  ControlIf cIf_nd4zNi0I;
  ControlIf cIf_hGsCfQAh;
  ControlBinop cBinop_tBR7baaq;
  ControlBinop cBinop_TIMpoD4k;
  ControlBinop cBinop_Y30G0XQZ;
  ControlBinop cBinop_vAjELRbq;
  ControlBinop cBinop_gWreoEss;
  ControlIf cIf_3Z3QPkGB;
  ControlBinop cBinop_NrFpU0zb;
  ControlBinop cBinop_ZkdKdSda;
  ControlBinop cBinop_C7W2Gcgb;
  ControlBinop cBinop_v7GZOga1;
  ControlBinop cBinop_bE6geKl7;
  ControlIf cIf_usE4JrlI;
  ControlSlice cSlice_3exyqq92;
  ControlVar cVar_znkDZzX3;
  ControlSlice cSlice_z0Mwm2o9;
  ControlVar cVar_gqY4cIii;
  ControlSlice cSlice_ZnBUfOxi;
  ControlVar cVar_EYVuXo4m;
  ControlSlice cSlice_vQ8wblyT;
  ControlVar cVar_okSjXXBl;
  ControlBinop cBinop_VCthhJzb;
  ControlBinop cBinop_Pjb3YJbS;
  ControlBinop cBinop_aLsUz4wg;
  ControlBinop cBinop_WFzz822P;
  ControlBinop cBinop_NwvyeKcG;
  ControlBinop cBinop_vRxfcNwk;
  ControlBinop cBinop_G1mF7cdB;
  ControlBinop cBinop_nCxva97k;
  ControlVar cVar_DDXofVmJ;
  ControlBinop cBinop_Lrn5QvoA;
  ControlBinop cBinop_j4CSXdCK;
  ControlBinop cBinop_ei4ZbXTJ;
  ControlBinop cBinop_juQBVugv;
  ControlBinop cBinop_xUDfVJaE;
  ControlBinop cBinop_jvSIRPNo;
  ControlBinop cBinop_0SUnKlv2;
  ControlBinop cBinop_NEIZwwDs;
  ControlVar cVar_lJtSPcrN;
  ControlVar cVar_5ullPkhk;
  ControlBinop cBinop_i2FZMwz6;
  ControlBinop cBinop_fNgxj8wy;
  ControlBinop cBinop_noX9dNLn;
  ControlBinop cBinop_AkDXwDQS;
  ControlBinop cBinop_uYsW2WOb;
  ControlBinop cBinop_AP2wre81;
  ControlBinop cBinop_vE5lf2eT;
  ControlBinop cBinop_sbJ5WtVh;
  ControlBinop cBinop_jK0wlST9;
  ControlBinop cBinop_EAKnaITK;
  ControlBinop cBinop_FqMRtYaf;
  ControlBinop cBinop_BlgAY3O6;
  ControlBinop cBinop_vP15EBzB;
  ControlBinop cBinop_eBmTx1Rg;
  ControlBinop cBinop_8aQaemHf;
  ControlBinop cBinop_1PACE8wS;
  ControlBinop cBinop_X1pRRZGq;
  ControlBinop cBinop_Iobg9z4T;
  ControlBinop cBinop_1RifQOWv;
  ControlBinop cBinop_4Hh7PxNS;
  ControlVar cVar_940BABzw;
  ControlVar cVar_srpxx87d;
  ControlVar cVar_bgVMHxDE;
  ControlBinop cBinop_fjxxsrq6;
  ControlBinop cBinop_7lt6dfEC;
  ControlBinop cBinop_WxNkBKUH;
  ControlBinop cBinop_IdUBFyRv;
  ControlBinop cBinop_kyezPcXC;
  ControlBinop cBinop_NbTMhvWS;
  ControlBinop cBinop_f6tg9iAf;
  ControlBinop cBinop_4d55udlw;
  ControlBinop cBinop_PMpKurWD;
  ControlBinop cBinop_G3csHPLy;
  ControlBinop cBinop_lJ3Q2Eal;
  ControlBinop cBinop_ziHvIVEM;
  ControlBinop cBinop_HNpH2rwW;
  ControlBinop cBinop_MpGEQ4rr;
  ControlBinop cBinop_QIDNPmbl;
  ControlBinop cBinop_kziPUw04;
  ControlBinop cBinop_pGieZkof;
  ControlBinop cBinop_OkQrgSbi;
  ControlBinop cBinop_BxRLR3qd;
  ControlBinop cBinop_Hj33HRH9;
  ControlBinop cBinop_bNUa8mbe;
  ControlBinop cBinop_3oYly2RX;
  ControlBinop cBinop_VNf7hBaJ;
  ControlVar cVar_92oDiSUv;
  ControlVar cVar_QR45SC4E;
  ControlVar cVar_v9XVEjpN;
  ControlBinop cBinop_iiZhhX4S;
  ControlBinop cBinop_WWg2kNYU;
  ControlBinop cBinop_akrPbuCH;
  ControlBinop cBinop_Zvyuz5xa;
  ControlBinop cBinop_krEdbSd7;
  ControlBinop cBinop_WXTO9lDt;
  ControlBinop cBinop_a4cIW8U6;
  ControlBinop cBinop_Mb4g1Eqy;
  ControlBinop cBinop_vgyDcdYg;
  ControlBinop cBinop_rttA8yEd;
  ControlBinop cBinop_nvUGMNR0;
  ControlBinop cBinop_s5m816Rf;
  SignalVarf sVarf_Orq0IBFi;
  SignalVarf sVarf_jFOaJVmt;
  SignalVarf sVarf_rc07Dvjq;
  ControlVar cVar_2OE4YqYJ;
  ControlVar cVar_DyH8jt41;
  ControlBinop cBinop_Tc7tWLu5;
  ControlBinop cBinop_zLa2UOOb;
  ControlBinop cBinop_Mg7hINB1;
  ControlBinop cBinop_SoUWv0n2;
  ControlBinop cBinop_KZarCtHm;
  ControlBinop cBinop_w7H7WGaS;
  ControlBinop cBinop_zYENA4fw;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
