/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_9To1tawT);
  numBytes += sLine_init(&sLine_JaFdJuzA);
  numBytes += sLine_init(&sLine_cQX4gkTi);
  numBytes += sLine_init(&sLine_I3xmZLEJ);
  numBytes += sLine_init(&sLine_hyyTcs33);
  numBytes += sBiquad_init(&sBiquad_s_vMW7mDXX);
  numBytes += sLine_init(&sLine_jfJXNnet);
  numBytes += sLine_init(&sLine_SYbVdvn5);
  numBytes += sLine_init(&sLine_gmjZZDck);
  numBytes += sLine_init(&sLine_IZuce8UZ);
  numBytes += sBiquad_init(&sBiquad_s_6Dcb8CgM);
  numBytes += sLine_init(&sLine_1lYcPAhh);
  numBytes += sLine_init(&sLine_F87Uv2ZV);
  numBytes += sLine_init(&sLine_ZrrU4hLz);
  numBytes += sLine_init(&sLine_DrWD2q9A);
  numBytes += sLine_init(&sLine_TzW55BTy);
  numBytes += sBiquad_init(&sBiquad_s_uwZmSxW2);
  numBytes += sLine_init(&sLine_tOw7tOrl);
  numBytes += sLine_init(&sLine_swExL2ol);
  numBytes += sLine_init(&sLine_49kQeaM4);
  numBytes += sLine_init(&sLine_NyTMpHVI);
  numBytes += sLine_init(&sLine_2FsznsLH);
  numBytes += sBiquad_init(&sBiquad_s_MPArQZDz);
  numBytes += sLine_init(&sLine_Y6OPGTqB);
  numBytes += sLine_init(&sLine_jiK1SahI);
  numBytes += sLine_init(&sLine_UbZyodiV);
  numBytes += sLine_init(&sLine_cMNSNtk7);
  numBytes += sBiquad_init(&sBiquad_s_baHuWTjy);
  numBytes += sLine_init(&sLine_PWGUA13Z);
  numBytes += sLine_init(&sLine_TJSbDrXr);
  numBytes += sLine_init(&sLine_fBMqWHs9);
  numBytes += sLine_init(&sLine_SSmEAjxG);
  numBytes += sLine_init(&sLine_R52th48k);
  numBytes += sBiquad_init(&sBiquad_s_A7pP8oqh);
  numBytes += cVar_init_f(&cVar_EsGliujI, 0.0f);
  numBytes += cVar_init_f(&cVar_bJiKbstv, 0.0f);
  numBytes += cVar_init_f(&cVar_BIplkXEe, 0.0f);
  numBytes += cVar_init_f(&cVar_csXr68E4, 0.0f);
  numBytes += cSlice_init(&cSlice_XYLMVRit, 1, -1);
  numBytes += cVar_init_f(&cVar_8Vd9WG7G, 1337.0f);
  numBytes += cVar_init_f(&cVar_RVSmOLvU, 0.0f);
  numBytes += cIf_init(&cIf_rs3vzxg9, false);
  numBytes += cIf_init(&cIf_E1epaEA0, false);
  numBytes += cBinop_init(&cBinop_g5cgkL4k, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pDexHgZx, false);
  numBytes += cBinop_init(&cBinop_KD5gzBaz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_aULe4Ul7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UQ52zhH0, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_N5oUqb6w, 0.0f);
  numBytes += cIf_init(&cIf_2U7qzEDB, false);
  numBytes += cIf_init(&cIf_LSWwkTPq, false);
  numBytes += cBinop_init(&cBinop_cU7sOGx7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_IRJMpD0v, false);
  numBytes += cBinop_init(&cBinop_ypgjzRA9, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_GvGzdFQE, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JVfiLBkF, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_3vKOD2iR, 0.0f);
  numBytes += cIf_init(&cIf_oudxjEzH, false);
  numBytes += cIf_init(&cIf_KNCkbcPy, false);
  numBytes += cBinop_init(&cBinop_r8HV9f3q, 0.0f); // __pow
  numBytes += cIf_init(&cIf_JY8EqUL6, false);
  numBytes += cBinop_init(&cBinop_hnrK1YHq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Bdv4qGsZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_63ranQsE, -15.0f); // __eq
  numBytes += cIf_init(&cIf_wfIl1Fg3, false);
  numBytes += cSlice_init(&cSlice_jTmCOrz3, 1, -1);
  numBytes += cVar_init_f(&cVar_YeAcDU0F, 0.0f);
  numBytes += cSlice_init(&cSlice_8SzcP5c3, 1, -1);
  numBytes += cVar_init_f(&cVar_2cE6aUHK, 0.0f);
  numBytes += cSlice_init(&cSlice_hHgy7qZF, 1, -1);
  numBytes += cVar_init_f(&cVar_jTs5aq5Y, 0.0f);
  numBytes += cSlice_init(&cSlice_w6lZni0w, 1, -1);
  numBytes += cVar_init_f(&cVar_6MX8qRbd, 0.313f);
  numBytes += cBinop_init(&cBinop_otP7W22g, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PhFCCROj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_B0HTVHvm, 0.0f);
  numBytes += cVar_init_f(&cVar_RTpqAJTj, 1337.0f);
  numBytes += cVar_init_f(&cVar_idvyDsbN, 0.3f);
  numBytes += cBinop_init(&cBinop_00v76p5n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zI7JY5EW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UwZ4YIot, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LeATHoyo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Whqj6COw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vOyzp1Gl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ePxioA3K, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Bs4Mt0tv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YfHWqxzL, 0.0f);
  numBytes += cVar_init_f(&cVar_7h9twssz, 1337.0f);
  numBytes += cVar_init_f(&cVar_qhZGqDaP, 0.313f);
  numBytes += cBinop_init(&cBinop_aDz9rBr7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SA5DWBc1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jd6mtT4i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iW8aKgqD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x5vwuEJG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ysiOL6mI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_eYNFTTZQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_G83uRciu, 0.0f);
  numBytes += cVar_init_f(&cVar_RKe87Zlf, 1037.0f);
  numBytes += cVar_init_f(&cVar_1AkFcxia, 0.4f);
  numBytes += cBinop_init(&cBinop_IqKigllM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gVmQIKyL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_X2OFKiXW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yMsigrBN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qUVbPodg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZY8SZff5, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_J2aAYIhf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wHtA0j19, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CeeyiJWK, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_nNd7LIUl, 1, -1);
  numBytes += cVar_init_f(&cVar_ZLAGVN56, 1337.0f);
  numBytes += cVar_init_f(&cVar_O3VmYZPK, 0.0f);
  numBytes += cIf_init(&cIf_4UG3gKss, false);
  numBytes += cIf_init(&cIf_DYmQzSF8, false);
  numBytes += cBinop_init(&cBinop_bpsGkUwx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_9QNlSVY7, false);
  numBytes += cBinop_init(&cBinop_o0tlyOh4, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_jLxehgjE, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_sxtRSKMJ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_h4JHj7nV, 0.0f);
  numBytes += cIf_init(&cIf_GAVNrx5L, false);
  numBytes += cIf_init(&cIf_KNvR3HUD, false);
  numBytes += cBinop_init(&cBinop_oj2JvtIQ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_kaIVEFOB, false);
  numBytes += cBinop_init(&cBinop_v3I13Te4, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_9NG0hXgg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_hQSPS8Jq, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JyVw9mrJ, 0.0f);
  numBytes += cIf_init(&cIf_nd4zNi0I, false);
  numBytes += cIf_init(&cIf_hGsCfQAh, false);
  numBytes += cBinop_init(&cBinop_tBR7baaq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3Z3QPkGB, false);
  numBytes += cBinop_init(&cBinop_C7W2Gcgb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_v7GZOga1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bE6geKl7, -15.0f); // __eq
  numBytes += cIf_init(&cIf_usE4JrlI, false);
  numBytes += cSlice_init(&cSlice_3exyqq92, 1, -1);
  numBytes += cVar_init_f(&cVar_znkDZzX3, 0.0f);
  numBytes += cSlice_init(&cSlice_z0Mwm2o9, 1, -1);
  numBytes += cVar_init_f(&cVar_gqY4cIii, 0.0f);
  numBytes += cSlice_init(&cSlice_ZnBUfOxi, 1, -1);
  numBytes += cVar_init_f(&cVar_EYVuXo4m, 0.0f);
  numBytes += cSlice_init(&cSlice_vQ8wblyT, 1, -1);
  numBytes += cVar_init_f(&cVar_okSjXXBl, 0.313f);
  numBytes += cBinop_init(&cBinop_Pjb3YJbS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_aLsUz4wg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DDXofVmJ, 0.0f);
  numBytes += cVar_init_f(&cVar_lJtSPcrN, 1337.0f);
  numBytes += cVar_init_f(&cVar_5ullPkhk, 0.3f);
  numBytes += cBinop_init(&cBinop_fNgxj8wy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uYsW2WOb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AP2wre81, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vE5lf2eT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sbJ5WtVh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jK0wlST9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FqMRtYaf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_BlgAY3O6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_940BABzw, 0.0f);
  numBytes += cVar_init_f(&cVar_srpxx87d, 1337.0f);
  numBytes += cVar_init_f(&cVar_bgVMHxDE, 0.313f);
  numBytes += cBinop_init(&cBinop_7lt6dfEC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kyezPcXC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NbTMhvWS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_f6tg9iAf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4d55udlw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G3csHPLy, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lJ3Q2Eal, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_92oDiSUv, 0.0f);
  numBytes += cVar_init_f(&cVar_QR45SC4E, 1037.0f);
  numBytes += cVar_init_f(&cVar_v9XVEjpN, 0.4f);
  numBytes += cBinop_init(&cBinop_WWg2kNYU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_krEdbSd7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WXTO9lDt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a4cIW8U6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Mb4g1Eqy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vgyDcdYg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Orq0IBFi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jFOaJVmt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rc07Dvjq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2OE4YqYJ, 5705.6f);
  numBytes += cVar_init_f(&cVar_DyH8jt41, 313.3f);
  numBytes += cBinop_init(&cBinop_Tc7tWLu5, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_zLa2UOOb, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Mg7hINB1, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y9mzQqTe_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3xJx7aFN_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mGdEGZXp_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JV2Tj9Hr_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CWo9ZkBa_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v5GxKbi3_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6P5D2JPp_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GeRfRBLY_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6HTpOp3V_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Eu8Yoes3_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BaYL5FQy_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KePWGtdR_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y3mlBxeA_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5FmsqTyb_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vRsCdxWd_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_60JkJTuV_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jcYUxbe9_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vqBETnka_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bGG2tuLS_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nfpTs1BM_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p6wRPT3k_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kcJmjQsm_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HJWVRqea_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e93N5RBb_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GIzjSxFd_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fm7zyJh0_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WLLTvbzV_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LUxUMqlg_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MEgzHM9u_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4UHmekKC_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IPO5pI7x_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9J8dxTuo_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iuH080zA_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_EsGliujI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ujdOhKbY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_bJiKbstv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Yag49oN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_BIplkXEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_thbPbLes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_csXr68E4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uQTRf3Zh_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NnpLPykZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YQCwz2Fo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iAfkz08V_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_YP8gU2R7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XYLMVRit, 0, m, &cSlice_XYLMVRit_sendMessage);
      break;
    }
    default: {
      cSwitchcase_grbaLwVd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_XYLMVRit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T79W2wKS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T79W2wKS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_8Vd9WG7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T79W2wKS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_T79W2wKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6P5D2JPp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_RVSmOLvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jixofFTb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rs3vzxg9, 0, m, &cIf_rs3vzxg9_sendMessage);
}

void Heavy_WSTD_3Q::cIf_rs3vzxg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_z5CGb9Lb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_E1epaEA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zjkJuSFw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OHtsCbvN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_iJhgwzGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g5cgkL4k, HV_BINOP_POW, 0, m, &cBinop_g5cgkL4k_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g5cgkL4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pDexHgZx, 0, m, &cIf_pDexHgZx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vLSQNtpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1I4wBptu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Yj3oyMvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E1epaEA0, 0, m, &cIf_E1epaEA0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uGOocB9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4qQhQj7o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4qQhQj7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E1epaEA0, 1, m, &cIf_E1epaEA0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OHtsCbvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vLSQNtpb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zjkJuSFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pDexHgZx, 0, m, &cIf_pDexHgZx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1I4wBptu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g5cgkL4k, HV_BINOP_POW, 1, m, &cBinop_g5cgkL4k_sendMessage);
  cMsg_iJhgwzGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_pDexHgZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_J2aAYIhf, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_jixofFTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rs3vzxg9, 1, m, &cIf_rs3vzxg9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z5CGb9Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aULe4Ul7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_aULe4Ul7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UQ52zhH0, HV_BINOP_EQ, 1, m, &cBinop_UQ52zhH0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3SmybP5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KD5gzBaz, HV_BINOP_ADD, 0, m, &cBinop_KD5gzBaz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KD5gzBaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uGOocB9s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yj3oyMvq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aULe4Ul7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pDexHgZx, 1, m, &cIf_pDexHgZx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UQ52zhH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fLK5AOGt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_fLK5AOGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_J2aAYIhf, m);
}

void Heavy_WSTD_3Q::cCast_z4EyZ91I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KD5gzBaz, HV_BINOP_ADD, 1, m, &cBinop_KD5gzBaz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aULe4Ul7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_aULe4Ul7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UQ52zhH0, HV_BINOP_EQ, 0, m, &cBinop_UQ52zhH0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Xn35SpdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3SmybP5d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_EcZmCWpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RVSmOLvU, 0, m, &cVar_RVSmOLvU_sendMessage);
}

void Heavy_WSTD_3Q::cVar_N5oUqb6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RoPNrkeX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2U7qzEDB, 0, m, &cIf_2U7qzEDB_sendMessage);
}

void Heavy_WSTD_3Q::cIf_2U7qzEDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_z2eFiXdn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_LSWwkTPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ljg2dy5F_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_n3NQlr13_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_k1UF8G6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cU7sOGx7, HV_BINOP_POW, 0, m, &cBinop_cU7sOGx7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cU7sOGx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IRJMpD0v, 0, m, &cIf_IRJMpD0v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zwvsQbFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_SlueqXoF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XqzK0w6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ac2uocE6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rkRpKW5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LSWwkTPq, 0, m, &cIf_LSWwkTPq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ac2uocE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LSWwkTPq, 1, m, &cIf_LSWwkTPq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_n3NQlr13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zwvsQbFj_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ljg2dy5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_IRJMpD0v, 0, m, &cIf_IRJMpD0v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SlueqXoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cU7sOGx7, HV_BINOP_POW, 1, m, &cBinop_cU7sOGx7_sendMessage);
  cMsg_k1UF8G6f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_IRJMpD0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0WNgQncq_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tytBvNTH_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Igkvl6qU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_RoPNrkeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2U7qzEDB, 1, m, &cIf_2U7qzEDB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z2eFiXdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GvGzdFQE, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GvGzdFQE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JVfiLBkF, HV_BINOP_EQ, 1, m, &cBinop_JVfiLBkF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ct9P5a61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ypgjzRA9, HV_BINOP_ADD, 0, m, &cBinop_ypgjzRA9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ypgjzRA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XqzK0w6b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rkRpKW5J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GvGzdFQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IRJMpD0v, 1, m, &cIf_IRJMpD0v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JVfiLBkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CfIZMLT2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_CfIZMLT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0WNgQncq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tytBvNTH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Igkvl6qU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Y1nnJvqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ypgjzRA9, HV_BINOP_ADD, 1, m, &cBinop_ypgjzRA9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GvGzdFQE, HV_BINOP_GREATER_THAN, 0, m, &cBinop_GvGzdFQE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JVfiLBkF, HV_BINOP_EQ, 0, m, &cBinop_JVfiLBkF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uOWds7vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N5oUqb6w, 0, m, &cVar_N5oUqb6w_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uxYAT05T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ct9P5a61_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_3vKOD2iR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hU5JTM3h_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oudxjEzH, 0, m, &cIf_oudxjEzH_sendMessage);
}

void Heavy_WSTD_3Q::cIf_oudxjEzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9ZbmrZxp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_KNCkbcPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zpM5oCNc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GH7chaYR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_DrrucpRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r8HV9f3q, HV_BINOP_POW, 0, m, &cBinop_r8HV9f3q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r8HV9f3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JY8EqUL6, 0, m, &cIf_JY8EqUL6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l03jzvAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jOjIBoo3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_i2Vw8OJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g385R5W0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PHhDtBLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KNCkbcPy, 0, m, &cIf_KNCkbcPy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g385R5W0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KNCkbcPy, 1, m, &cIf_KNCkbcPy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GH7chaYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_l03jzvAR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zpM5oCNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JY8EqUL6, 0, m, &cIf_JY8EqUL6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jOjIBoo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r8HV9f3q, HV_BINOP_POW, 1, m, &cBinop_r8HV9f3q_sendMessage);
  cMsg_DrrucpRA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_JY8EqUL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_CeeyiJWK, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_hU5JTM3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oudxjEzH, 1, m, &cIf_oudxjEzH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9ZbmrZxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bdv4qGsZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Bdv4qGsZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_63ranQsE, HV_BINOP_EQ, 1, m, &cBinop_63ranQsE_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9l0vFber_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hnrK1YHq, HV_BINOP_ADD, 0, m, &cBinop_hnrK1YHq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hnrK1YHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i2Vw8OJh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PHhDtBLd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Bdv4qGsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JY8EqUL6, 1, m, &cIf_JY8EqUL6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_63ranQsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YF44xWEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_YF44xWEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CeeyiJWK, m);
}

void Heavy_WSTD_3Q::cCast_ImA6N8N5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3vKOD2iR, 0, m, &cVar_3vKOD2iR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Rcpzkupx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9l0vFber_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_ZggPZmM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hnrK1YHq, HV_BINOP_ADD, 1, m, &cBinop_hnrK1YHq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bdv4qGsZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Bdv4qGsZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_63ranQsE, HV_BINOP_EQ, 0, m, &cBinop_63ranQsE_sendMessage);
}

void Heavy_WSTD_3Q::cIf_wfIl1Fg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wHtA0j19, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_RUEm8HeQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jTmCOrz3, 0, m, &cSlice_jTmCOrz3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wlo5Jh2s_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_jTmCOrz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ho1BHrI6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ho1BHrI6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_YeAcDU0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ho1BHrI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Ho1BHrI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CWo9ZkBa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_wlo5Jh2s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8SzcP5c3, 0, m, &cSlice_8SzcP5c3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YP8gU2R7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_8SzcP5c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JLmdstOu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JLmdstOu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_2cE6aUHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JLmdstOu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JLmdstOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6HTpOp3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_grbaLwVd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hHgy7qZF, 0, m, &cSlice_hHgy7qZF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HPVjGA81_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_hHgy7qZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iLrpeiXZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iLrpeiXZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_jTs5aq5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iLrpeiXZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iLrpeiXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_v5GxKbi3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_HPVjGA81_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w6lZni0w, 0, m, &cSlice_w6lZni0w_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_w6lZni0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O4WaHiJv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O4WaHiJv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_6MX8qRbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O4WaHiJv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_O4WaHiJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GeRfRBLY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_tCyHfvPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9To1tawT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dilMSleS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JaFdJuzA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zqHyGHfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cQX4gkTi, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_G9IiNlhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I3xmZLEJ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vyjvC7x8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hyyTcs33, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_sIsnBiuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_moEP29Y1_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_moEP29Y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_otP7W22g, HV_BINOP_DIVIDE, 1, m, &cBinop_otP7W22g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pYNS7L4z_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Z8TbUMZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fEayaJ1O_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Qcm48CVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Z8TbUMZ0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fEayaJ1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_otP7W22g, HV_BINOP_DIVIDE, 0, m, &cBinop_otP7W22g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pYNS7L4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qcm48CVb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_otP7W22g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhFCCROj, HV_BINOP_MULTIPLY, 1, m, &cBinop_PhFCCROj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PhFCCROj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QLIN71bw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZG3m1sYn_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_MPooXx3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UMst69hb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_l9mAdJyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gRxncBWy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kOht25DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Dub16NsQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Dub16NsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhFCCROj, HV_BINOP_MULTIPLY, 0, m, &cBinop_PhFCCROj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AOF0CYv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5qziJcvj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5qziJcvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x5ZRmQW6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_a5dWdj0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B0HTVHvm, 1, m, &cVar_B0HTVHvm_sendMessage);
}

void Heavy_WSTD_3Q::cVar_B0HTVHvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RK68Gk4F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OHaxP6TY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zI7JY5EW, HV_BINOP_MULTIPLY, 1, m, &cBinop_zI7JY5EW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TdurPOYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OHaxP6TY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rVbYRZH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hBK8phvD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hBK8phvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwZ4YIot, HV_BINOP_MULTIPLY, 1, m, &cBinop_UwZ4YIot_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NqJCMKOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LeATHoyo, HV_BINOP_MULTIPLY, 1, m, &cBinop_LeATHoyo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RvaF2k6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NqJCMKOi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7mqmn5vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Whqj6COw, HV_BINOP_MULTIPLY, 1, m, &cBinop_Whqj6COw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_sGPMSFrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ht0TDCuU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ht0TDCuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vOyzp1Gl, HV_BINOP_MULTIPLY, 1, m, &cBinop_vOyzp1Gl_sendMessage);
}

void Heavy_WSTD_3Q::cVar_RTpqAJTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hzeal3YT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_kOht25DF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rcutM6L4_sendMessage);
}

void Heavy_WSTD_3Q::cVar_idvyDsbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_AOF0CYv2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZG3m1sYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_l9mAdJyA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QLIN71bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MPooXx3c_sendMessage);
}

void Heavy_WSTD_3Q::cSend_UMst69hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KePWGtdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_gRxncBWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BaYL5FQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_FaMe3Y7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Eu8Yoes3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_x5ZRmQW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_N6eUXcTW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N6eUXcTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_00v76p5n, HV_BINOP_MULTIPLY, 1, m, &cBinop_00v76p5n_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_00v76p5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LvGDiIkQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LvGDiIkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FaMe3Y7q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_RK68Gk4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ddmy9uyj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ddmy9uyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rbaZGjo8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b6Dnue3a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vOWZV6mK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gh7mHjyI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8ObTs7at_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TL8mOryt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zI7JY5EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tCyHfvPN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UwZ4YIot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dilMSleS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LeATHoyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zqHyGHfG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Whqj6COw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G9IiNlhQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vOyzp1Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vyjvC7x8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_KOytRGg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_idvyDsbN, 1, m, &cVar_idvyDsbN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xUKe9scy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RTpqAJTj, 0, m, &cVar_RTpqAJTj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8ObTs7at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwZ4YIot, HV_BINOP_MULTIPLY, 0, m, &cBinop_UwZ4YIot_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rbaZGjo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_b6Dnue3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vOyzp1Gl, HV_BINOP_MULTIPLY, 0, m, &cBinop_vOyzp1Gl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TL8mOryt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zI7JY5EW, HV_BINOP_MULTIPLY, 0, m, &cBinop_zI7JY5EW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vOWZV6mK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Whqj6COw, HV_BINOP_MULTIPLY, 0, m, &cBinop_Whqj6COw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Gh7mHjyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LeATHoyo, HV_BINOP_MULTIPLY, 0, m, &cBinop_LeATHoyo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hzeal3YT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_idvyDsbN, 0, m, &cVar_idvyDsbN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rcutM6L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B0HTVHvm, 0, m, &cVar_B0HTVHvm_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vuT5bqwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jfJXNnet, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_pSgF3LOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SYbVdvn5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lf37bLi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gmjZZDck, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_DuhORFJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IZuce8UZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_DwSeUiLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wDrY0ZXG_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_wDrY0ZXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ePxioA3K, HV_BINOP_DIVIDE, 1, m, &cBinop_ePxioA3K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O51SMjEb_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_QCGFxGx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RyZsZgLg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nW9dg6wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_QCGFxGx1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RyZsZgLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ePxioA3K, HV_BINOP_DIVIDE, 0, m, &cBinop_ePxioA3K_sendMessage);
}

void Heavy_WSTD_3Q::cCast_O51SMjEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nW9dg6wn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ePxioA3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bs4Mt0tv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bs4Mt0tv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Bs4Mt0tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yyw9sKpd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nhVJUY5r_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_5r7hJdxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_otY9jRDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_GVQQhEJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y2MPp9nD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YhwP1UBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_SMLMFosP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SMLMFosP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bs4Mt0tv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bs4Mt0tv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gkL89mjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9YE7vstl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9YE7vstl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KzVuaJ5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Ww7Cikae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jd6mtT4i, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jd6mtT4i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_D5Rwbf7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YfHWqxzL, 1, m, &cVar_YfHWqxzL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s57I4r9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iW8aKgqD, HV_BINOP_MULTIPLY, 1, m, &cBinop_iW8aKgqD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_QOyAL59m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2Ob83CSX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2Ob83CSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5vwuEJG, HV_BINOP_MULTIPLY, 1, m, &cBinop_x5vwuEJG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_YfHWqxzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zjvwwnv2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_7h9twssz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WzhEty62_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_YhwP1UBn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5TTeWf6D_sendMessage);
}

void Heavy_WSTD_3Q::cVar_qhZGqDaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gkL89mjN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yyw9sKpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5r7hJdxi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nhVJUY5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_GVQQhEJd_sendMessage);
}

void Heavy_WSTD_3Q::cSend_otY9jRDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vRsCdxWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_y2MPp9nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5FmsqTyb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Ugepb24B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Y3mlBxeA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KzVuaJ5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uBSRyQpc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uBSRyQpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aDz9rBr7, HV_BINOP_MULTIPLY, 1, m, &cBinop_aDz9rBr7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aDz9rBr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JxZcBwDX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JxZcBwDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ugepb24B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Zjvwwnv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_a2FIRE2Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a2FIRE2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DNlE6RYp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rXw9hLRV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fu5fYt1D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iWvHnukm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SA5DWBc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vuT5bqwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Jd6mtT4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSgF3LOB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iW8aKgqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lf37bLi5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_x5vwuEJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DuhORFJA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_rfPcgBxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7h9twssz, 0, m, &cVar_7h9twssz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lSW6slHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qhZGqDaP, 1, m, &cVar_qhZGqDaP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5TTeWf6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YfHWqxzL, 0, m, &cVar_YfHWqxzL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WzhEty62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qhZGqDaP, 0, m, &cVar_qhZGqDaP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DNlE6RYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5vwuEJG, HV_BINOP_MULTIPLY, 0, m, &cBinop_x5vwuEJG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Fu5fYt1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jd6mtT4i, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jd6mtT4i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iWvHnukm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SA5DWBc1, HV_BINOP_MULTIPLY, 0, m, &cBinop_SA5DWBc1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rXw9hLRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iW8aKgqD, HV_BINOP_MULTIPLY, 0, m, &cBinop_iW8aKgqD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_N7C4yMKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1lYcPAhh, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_pbPFpir3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F87Uv2ZV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ja6d5w0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZrrU4hLz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hJRi6Yl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DrWD2q9A, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6nUa3Kei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TzW55BTy, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_niJ3gNpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8DBzelOV_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_8DBzelOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ysiOL6mI, HV_BINOP_DIVIDE, 1, m, &cBinop_ysiOL6mI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_45Tj8CSK_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qUPRIn3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2z2nk9fT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_oAPtVwNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_qUPRIn3f_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2z2nk9fT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ysiOL6mI, HV_BINOP_DIVIDE, 0, m, &cBinop_ysiOL6mI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_45Tj8CSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oAPtVwNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ysiOL6mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eYNFTTZQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_eYNFTTZQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eYNFTTZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_86nSAeDT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sWDJxWjY_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_5tRNF1Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hst8jjrr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_kXWsTA07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yTUgsCFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_aJ63FSr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_iMxkVPGA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iMxkVPGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eYNFTTZQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_eYNFTTZQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_duHZtftt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_btNvRMPN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_btNvRMPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IUN9NT2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FETCw3hh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gVmQIKyL, HV_BINOP_MULTIPLY, 1, m, &cBinop_gVmQIKyL_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_l8i4xRO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LLSrMk6P_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LLSrMk6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FETCw3hh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_K91xIFaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_De7AY1J3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_De7AY1J3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X2OFKiXW, HV_BINOP_MULTIPLY, 1, m, &cBinop_X2OFKiXW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EjvXYTIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yMsigrBN, HV_BINOP_MULTIPLY, 1, m, &cBinop_yMsigrBN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bVz9OEtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_utAlwR00_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_utAlwR00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EjvXYTIa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mcvzJ6Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G83uRciu, 1, m, &cVar_G83uRciu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K5GDFJFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qUVbPodg, HV_BINOP_MULTIPLY, 1, m, &cBinop_qUVbPodg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ntec8pNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_33kuMvZZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_33kuMvZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZY8SZff5, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZY8SZff5_sendMessage);
}

void Heavy_WSTD_3Q::cVar_G83uRciu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4hqTYTv0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_RKe87Zlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_04BDE6mz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_aJ63FSr1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gu2ky7Qx_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1AkFcxia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_duHZtftt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sWDJxWjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_kXWsTA07_sendMessage);
}

void Heavy_WSTD_3Q::cCast_86nSAeDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5tRNF1Wl_sendMessage);
}

void Heavy_WSTD_3Q::cSend_hst8jjrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vqBETnka_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_yTUgsCFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jcYUxbe9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_y0wkiBjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_60JkJTuV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IUN9NT2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uz35pKJ5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uz35pKJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IqKigllM, HV_BINOP_MULTIPLY, 1, m, &cBinop_IqKigllM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IqKigllM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Rzvi99ak_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rzvi99ak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y0wkiBjc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_4hqTYTv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wMWNXulG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wMWNXulG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4umkY34D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NsSMgA91_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_drrJVNSw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0eUQv4Qs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ovQeZiAj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R6m3pRfm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gVmQIKyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N7C4yMKP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_X2OFKiXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbPFpir3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yMsigrBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ja6d5w0Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qUVbPodg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hJRi6Yl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZY8SZff5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6nUa3Kei_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_km74I59G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1AkFcxia, 1, m, &cVar_1AkFcxia_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lJj6TZeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RKe87Zlf, 0, m, &cVar_RKe87Zlf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4umkY34D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_drrJVNSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qUVbPodg, HV_BINOP_MULTIPLY, 0, m, &cBinop_qUVbPodg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ovQeZiAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X2OFKiXW, HV_BINOP_MULTIPLY, 0, m, &cBinop_X2OFKiXW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_R6m3pRfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gVmQIKyL, HV_BINOP_MULTIPLY, 0, m, &cBinop_gVmQIKyL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0eUQv4Qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yMsigrBN, HV_BINOP_MULTIPLY, 0, m, &cBinop_yMsigrBN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NsSMgA91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZY8SZff5, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZY8SZff5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_04BDE6mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1AkFcxia, 0, m, &cVar_1AkFcxia_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gu2ky7Qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G83uRciu, 0, m, &cVar_G83uRciu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0WNgQncq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wfIl1Fg3, 1, m, &cIf_wfIl1Fg3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ElQAkhA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wHtA0j19, m);
}

void Heavy_WSTD_3Q::cBinop_tytBvNTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ElQAkhA6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Igkvl6qU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wfIl1Fg3, 0, m, &cIf_wfIl1Fg3_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_ttxiK17p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nNd7LIUl, 0, m, &cSlice_nNd7LIUl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n2JmyrMW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_nNd7LIUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vnpoyFso_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vnpoyFso_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ZLAGVN56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vnpoyFso_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vnpoyFso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p6wRPT3k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_O3VmYZPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YXGJ06m9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_4UG3gKss, 0, m, &cIf_4UG3gKss_sendMessage);
}

void Heavy_WSTD_3Q::cIf_4UG3gKss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tpEmeeQ8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_DYmQzSF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_BNvHOaI2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_27YJvkgN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_5y8VDx11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bpsGkUwx, HV_BINOP_POW, 0, m, &cBinop_bpsGkUwx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bpsGkUwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9QNlSVY7, 0, m, &cIf_9QNlSVY7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pIrj3070_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2KZ9BeOM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j2ErBzJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DYmQzSF8, 0, m, &cIf_DYmQzSF8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aXDZ8yLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JSkGpso1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JSkGpso1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DYmQzSF8, 1, m, &cIf_DYmQzSF8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_27YJvkgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pIrj3070_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BNvHOaI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9QNlSVY7, 0, m, &cIf_9QNlSVY7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2KZ9BeOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bpsGkUwx, HV_BINOP_POW, 1, m, &cBinop_bpsGkUwx_sendMessage);
  cMsg_5y8VDx11_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_9QNlSVY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Orq0IBFi, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_YXGJ06m9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4UG3gKss, 1, m, &cIf_4UG3gKss_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tpEmeeQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jLxehgjE, HV_BINOP_GREATER_THAN, 1, m, &cBinop_jLxehgjE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sxtRSKMJ, HV_BINOP_EQ, 1, m, &cBinop_sxtRSKMJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_o5MkH9EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o0tlyOh4, HV_BINOP_ADD, 0, m, &cBinop_o0tlyOh4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_o0tlyOh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aXDZ8yLJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j2ErBzJ1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jLxehgjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9QNlSVY7, 1, m, &cIf_9QNlSVY7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sxtRSKMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KMlynTdz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KMlynTdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Orq0IBFi, m);
}

void Heavy_WSTD_3Q::cCast_NfH6EchX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o0tlyOh4, HV_BINOP_ADD, 1, m, &cBinop_o0tlyOh4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jLxehgjE, HV_BINOP_GREATER_THAN, 0, m, &cBinop_jLxehgjE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sxtRSKMJ, HV_BINOP_EQ, 0, m, &cBinop_sxtRSKMJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dqRlqGOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O3VmYZPK, 0, m, &cVar_O3VmYZPK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zL7egbeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o5MkH9EF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_h4JHj7nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cL55hpaC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_GAVNrx5L, 0, m, &cIf_GAVNrx5L_sendMessage);
}

void Heavy_WSTD_3Q::cIf_GAVNrx5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kiIaFiff_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_KNvR3HUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SiUtbYu2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NcPZpKMr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_bur0VQqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oj2JvtIQ, HV_BINOP_POW, 0, m, &cBinop_oj2JvtIQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oj2JvtIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kaIVEFOB, 0, m, &cIf_kaIVEFOB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fAJJuk2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dEFmZFWs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iJ9RGxPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KNvR3HUD, 0, m, &cIf_KNvR3HUD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_798ysmtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CMxpG5Re_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CMxpG5Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KNvR3HUD, 1, m, &cIf_KNvR3HUD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NcPZpKMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fAJJuk2S_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SiUtbYu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kaIVEFOB, 0, m, &cIf_kaIVEFOB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dEFmZFWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oj2JvtIQ, HV_BINOP_POW, 1, m, &cBinop_oj2JvtIQ_sendMessage);
  cMsg_bur0VQqX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_kaIVEFOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rttA8yEd_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nvUGMNR0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_s5m816Rf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_cL55hpaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GAVNrx5L, 1, m, &cIf_GAVNrx5L_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kiIaFiff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9NG0hXgg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_9NG0hXgg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQSPS8Jq, HV_BINOP_EQ, 1, m, &cBinop_hQSPS8Jq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qDKpXXR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v3I13Te4, HV_BINOP_ADD, 0, m, &cBinop_v3I13Te4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_v3I13Te4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_798ysmtv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iJ9RGxPO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9NG0hXgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kaIVEFOB, 1, m, &cIf_kaIVEFOB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hQSPS8Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cSDhBRMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_cSDhBRMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rttA8yEd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nvUGMNR0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_s5m816Rf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_H3PsYCEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qDKpXXR4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_LgVxQb4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h4JHj7nV, 0, m, &cVar_h4JHj7nV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3MbClTos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v3I13Te4, HV_BINOP_ADD, 1, m, &cBinop_v3I13Te4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9NG0hXgg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_9NG0hXgg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQSPS8Jq, HV_BINOP_EQ, 0, m, &cBinop_hQSPS8Jq_sendMessage);
}

void Heavy_WSTD_3Q::cVar_JyVw9mrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NrFpU0zb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_nd4zNi0I, 0, m, &cIf_nd4zNi0I_sendMessage);
}

void Heavy_WSTD_3Q::cIf_nd4zNi0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZkdKdSda_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_hGsCfQAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QfNjr9Dh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_vAjELRbq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_IDljmOVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tBR7baaq, HV_BINOP_POW, 0, m, &cBinop_tBR7baaq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tBR7baaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Z3QPkGB, 0, m, &cIf_3Z3QPkGB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TIMpoD4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gWreoEss_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VcmqL5Fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hGsCfQAh, 0, m, &cIf_hGsCfQAh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tNb0Iivp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Y30G0XQZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Y30G0XQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hGsCfQAh, 1, m, &cIf_hGsCfQAh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vAjELRbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TIMpoD4k_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_QfNjr9Dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3Z3QPkGB, 0, m, &cIf_3Z3QPkGB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gWreoEss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tBR7baaq, HV_BINOP_POW, 1, m, &cBinop_tBR7baaq_sendMessage);
  cMsg_IDljmOVx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_3Z3QPkGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_rc07Dvjq, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_NrFpU0zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nd4zNi0I, 1, m, &cIf_nd4zNi0I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZkdKdSda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v7GZOga1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_v7GZOga1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bE6geKl7, HV_BINOP_EQ, 1, m, &cBinop_bE6geKl7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_y7UfVA8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C7W2Gcgb, HV_BINOP_ADD, 0, m, &cBinop_C7W2Gcgb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_C7W2Gcgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tNb0Iivp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VcmqL5Fj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_v7GZOga1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Z3QPkGB, 1, m, &cIf_3Z3QPkGB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bE6geKl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LZCF3WLZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_LZCF3WLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rc07Dvjq, m);
}

void Heavy_WSTD_3Q::cCast_pM2NsgkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C7W2Gcgb, HV_BINOP_ADD, 1, m, &cBinop_C7W2Gcgb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v7GZOga1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_v7GZOga1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bE6geKl7, HV_BINOP_EQ, 0, m, &cBinop_bE6geKl7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Gdb6QAUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y7UfVA8p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_a0DvGzcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JyVw9mrJ, 0, m, &cVar_JyVw9mrJ_sendMessage);
}

void Heavy_WSTD_3Q::cIf_usE4JrlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jFOaJVmt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_z2dsOwoU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3exyqq92, 0, m, &cSlice_3exyqq92_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VWHttao2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_3exyqq92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7hAkszwF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7hAkszwF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_znkDZzX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7hAkszwF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7hAkszwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bGG2tuLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_VWHttao2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z0Mwm2o9, 0, m, &cSlice_z0Mwm2o9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ttxiK17p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_z0Mwm2o9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_04mdstHy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_04mdstHy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_gqY4cIii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_04mdstHy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_04mdstHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HJWVRqea_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_n2JmyrMW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZnBUfOxi, 0, m, &cSlice_ZnBUfOxi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YofdijpM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_ZnBUfOxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1FfkNicO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1FfkNicO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_EYVuXo4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1FfkNicO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_1FfkNicO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nfpTs1BM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_YofdijpM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vQ8wblyT, 0, m, &cSlice_vQ8wblyT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_vQ8wblyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9fWXfhig_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9fWXfhig_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_okSjXXBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9fWXfhig_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_9fWXfhig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kcJmjQsm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_pAWzo1lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tOw7tOrl, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_CEvug11N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_swExL2ol, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dCOqigdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_49kQeaM4, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ghaDU5Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NyTMpHVI, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0FT2DuCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2FsznsLH, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_IIu1c9vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yjgVTEq9_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_yjgVTEq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pjb3YJbS, HV_BINOP_DIVIDE, 1, m, &cBinop_Pjb3YJbS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t4tNhlcG_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_xZUuBONJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VCthhJzb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DyZNtwpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xZUuBONJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VCthhJzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pjb3YJbS, HV_BINOP_DIVIDE, 0, m, &cBinop_Pjb3YJbS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_t4tNhlcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DyZNtwpL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Pjb3YJbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aLsUz4wg, HV_BINOP_MULTIPLY, 1, m, &cBinop_aLsUz4wg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aLsUz4wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZNteDVYS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OiZ4lrYM_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_QZVPdhhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CHjkJZ21_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_ncB82BBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_um2sd3P0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WFzz822P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NwvyeKcG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NwvyeKcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aLsUz4wg, HV_BINOP_MULTIPLY, 0, m, &cBinop_aLsUz4wg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vRxfcNwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_G1mF7cdB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G1mF7cdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NFAnKwnO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nCxva97k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DDXofVmJ, 1, m, &cVar_DDXofVmJ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_DDXofVmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJepDlYo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Lrn5QvoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYsW2WOb, HV_BINOP_MULTIPLY, 1, m, &cBinop_uYsW2WOb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j4CSXdCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Lrn5QvoA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ei4ZbXTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_juQBVugv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_juQBVugv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AP2wre81, HV_BINOP_MULTIPLY, 1, m, &cBinop_AP2wre81_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xUDfVJaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vE5lf2eT, HV_BINOP_MULTIPLY, 1, m, &cBinop_vE5lf2eT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jvSIRPNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xUDfVJaE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0SUnKlv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sbJ5WtVh, HV_BINOP_MULTIPLY, 1, m, &cBinop_sbJ5WtVh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ueizxBQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NEIZwwDs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NEIZwwDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jK0wlST9, HV_BINOP_MULTIPLY, 1, m, &cBinop_jK0wlST9_sendMessage);
}

void Heavy_WSTD_3Q::cVar_lJtSPcrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iZkqZGLj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WFzz822P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8MYF87gA_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5ullPkhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vRxfcNwk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OiZ4lrYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ncB82BBs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZNteDVYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QZVPdhhV_sendMessage);
}

void Heavy_WSTD_3Q::cSend_CHjkJZ21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fm7zyJh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_um2sd3P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GIzjSxFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Mkmg1Yvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e93N5RBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_NFAnKwnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_i2FZMwz6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i2FZMwz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fNgxj8wy, HV_BINOP_MULTIPLY, 1, m, &cBinop_fNgxj8wy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fNgxj8wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_noX9dNLn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_noX9dNLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mkmg1Yvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_cJepDlYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AkDXwDQS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AkDXwDQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Je9zqf6k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_50pTECFx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FxsI92pk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_plP0mJHT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0KzVzsiL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xNwUtgBZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uYsW2WOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pAWzo1lg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_AP2wre81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CEvug11N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vE5lf2eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dCOqigdJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sbJ5WtVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ghaDU5Tj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jK0wlST9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0FT2DuCx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_7wzqITpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ullPkhk, 1, m, &cVar_5ullPkhk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LySn4APX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lJtSPcrN, 0, m, &cVar_lJtSPcrN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Je9zqf6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_plP0mJHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vE5lf2eT, HV_BINOP_MULTIPLY, 0, m, &cBinop_vE5lf2eT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0KzVzsiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AP2wre81, HV_BINOP_MULTIPLY, 0, m, &cBinop_AP2wre81_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FxsI92pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sbJ5WtVh, HV_BINOP_MULTIPLY, 0, m, &cBinop_sbJ5WtVh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_50pTECFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jK0wlST9, HV_BINOP_MULTIPLY, 0, m, &cBinop_jK0wlST9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xNwUtgBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYsW2WOb, HV_BINOP_MULTIPLY, 0, m, &cBinop_uYsW2WOb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iZkqZGLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ullPkhk, 0, m, &cVar_5ullPkhk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8MYF87gA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DDXofVmJ, 0, m, &cVar_DDXofVmJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ypP5Ne09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y6OPGTqB, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aVfdoSZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jiK1SahI, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RXQSQnFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UbZyodiV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5nwpgigf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cMNSNtk7, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BVOUafMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_canWhiXp_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_canWhiXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqMRtYaf, HV_BINOP_DIVIDE, 1, m, &cBinop_FqMRtYaf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_otIWdudW_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_xr1JuR65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_EAKnaITK_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YAMTZxSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xr1JuR65_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EAKnaITK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqMRtYaf, HV_BINOP_DIVIDE, 0, m, &cBinop_FqMRtYaf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_otIWdudW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YAMTZxSx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FqMRtYaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BlgAY3O6, HV_BINOP_MULTIPLY, 1, m, &cBinop_BlgAY3O6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BlgAY3O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TlnKfVQz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G6a7jaII_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_jzBFIFfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2n9R2c5U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_TRwPgB9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Kg1t7SPC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vP15EBzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eBmTx1Rg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eBmTx1Rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BlgAY3O6, HV_BINOP_MULTIPLY, 0, m, &cBinop_BlgAY3O6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8aQaemHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1PACE8wS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1PACE8wS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_err1amxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_X1pRRZGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NbTMhvWS, HV_BINOP_MULTIPLY, 1, m, &cBinop_NbTMhvWS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Iobg9z4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_940BABzw, 1, m, &cVar_940BABzw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1RifQOWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f6tg9iAf, HV_BINOP_MULTIPLY, 1, m, &cBinop_f6tg9iAf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qDZlWAdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4Hh7PxNS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4Hh7PxNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4d55udlw, HV_BINOP_MULTIPLY, 1, m, &cBinop_4d55udlw_sendMessage);
}

void Heavy_WSTD_3Q::cVar_940BABzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lUCjW63k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_srpxx87d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MqdKJ6ix_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_vP15EBzB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ou4frpqO_sendMessage);
}

void Heavy_WSTD_3Q::cVar_bgVMHxDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8aQaemHf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TlnKfVQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_jzBFIFfN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_G6a7jaII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TRwPgB9o_sendMessage);
}

void Heavy_WSTD_3Q::cSend_2n9R2c5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MEgzHM9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Kg1t7SPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LUxUMqlg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_c8zE0x4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WLLTvbzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_err1amxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fjxxsrq6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fjxxsrq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7lt6dfEC, HV_BINOP_MULTIPLY, 1, m, &cBinop_7lt6dfEC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7lt6dfEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WxNkBKUH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WxNkBKUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c8zE0x4j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lUCjW63k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IdUBFyRv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IdUBFyRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cr2AsPpI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ZpmrRBo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h9n9m421_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KAGP7O6i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kyezPcXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypP5Ne09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_NbTMhvWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aVfdoSZj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_f6tg9iAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXQSQnFS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4d55udlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5nwpgigf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Uwtvks7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bgVMHxDE, 1, m, &cVar_bgVMHxDE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BsfQRBSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_srpxx87d, 0, m, &cVar_srpxx87d_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MqdKJ6ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bgVMHxDE, 0, m, &cVar_bgVMHxDE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ou4frpqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_940BABzw, 0, m, &cVar_940BABzw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0ZpmrRBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f6tg9iAf, HV_BINOP_MULTIPLY, 0, m, &cBinop_f6tg9iAf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KAGP7O6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kyezPcXC, HV_BINOP_MULTIPLY, 0, m, &cBinop_kyezPcXC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_h9n9m421_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NbTMhvWS, HV_BINOP_MULTIPLY, 0, m, &cBinop_NbTMhvWS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Cr2AsPpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4d55udlw, HV_BINOP_MULTIPLY, 0, m, &cBinop_4d55udlw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SnjJpIA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PWGUA13Z, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_s17a0MeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TJSbDrXr, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yfTN2JIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fBMqWHs9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6aURy5Qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SSmEAjxG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XwCnE1OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R52th48k, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_f5XeLr2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_V840hgCB_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_V840hgCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G3csHPLy, HV_BINOP_DIVIDE, 1, m, &cBinop_G3csHPLy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LJ7jyv1X_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_KiVtWnDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_PMpKurWD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FlaYJ4Eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_KiVtWnDS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PMpKurWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G3csHPLy, HV_BINOP_DIVIDE, 0, m, &cBinop_G3csHPLy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LJ7jyv1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FlaYJ4Eo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_G3csHPLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJ3Q2Eal, HV_BINOP_MULTIPLY, 1, m, &cBinop_lJ3Q2Eal_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lJ3Q2Eal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DsLv7c4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HvhlIeST_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_6SGw7XDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yxdkpxNY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_hLHvs2XG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S5P1FTfQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ziHvIVEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HNpH2rwW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HNpH2rwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJ3Q2Eal, HV_BINOP_MULTIPLY, 0, m, &cBinop_lJ3Q2Eal_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MpGEQ4rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QIDNPmbl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QIDNPmbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xYu9c4sR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kziPUw04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_krEdbSd7, HV_BINOP_MULTIPLY, 1, m, &cBinop_krEdbSd7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_woKKPJJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pGieZkof_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pGieZkof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kziPUw04_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UP8WVXNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OkQrgSbi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OkQrgSbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WXTO9lDt, HV_BINOP_MULTIPLY, 1, m, &cBinop_WXTO9lDt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BxRLR3qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a4cIW8U6, HV_BINOP_MULTIPLY, 1, m, &cBinop_a4cIW8U6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_n6vxQLvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Hj33HRH9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Hj33HRH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BxRLR3qd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bNUa8mbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_92oDiSUv, 1, m, &cVar_92oDiSUv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3oYly2RX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mb4g1Eqy, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mb4g1Eqy_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zwhVIUqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VNf7hBaJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VNf7hBaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vgyDcdYg, HV_BINOP_MULTIPLY, 1, m, &cBinop_vgyDcdYg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_92oDiSUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l3Feh99a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_QR45SC4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ShPEfRV9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ziHvIVEM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h3fZpP8n_sendMessage);
}

void Heavy_WSTD_3Q::cVar_v9XVEjpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MpGEQ4rr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DsLv7c4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6SGw7XDc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HvhlIeST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_hLHvs2XG_sendMessage);
}

void Heavy_WSTD_3Q::cSend_yxdkpxNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9J8dxTuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_S5P1FTfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IPO5pI7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_C4MywSyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4UHmekKC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_xYu9c4sR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iiZhhX4S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iiZhhX4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WWg2kNYU, HV_BINOP_MULTIPLY, 1, m, &cBinop_WWg2kNYU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WWg2kNYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_akrPbuCH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_akrPbuCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C4MywSyp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_l3Feh99a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Zvyuz5xa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zvyuz5xa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j0d5llXR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NOdwA1o9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mW1DGpPc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T8JvQ0hA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zKEGsxEQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4BS2ZfmJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_krEdbSd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SnjJpIA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WXTO9lDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s17a0MeH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_a4cIW8U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yfTN2JIG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Mb4g1Eqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aURy5Qo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vgyDcdYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XwCnE1OU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_mmyR4rNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v9XVEjpN, 1, m, &cVar_v9XVEjpN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OORjgnhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QR45SC4E, 0, m, &cVar_QR45SC4E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zKEGsxEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WXTO9lDt, HV_BINOP_MULTIPLY, 0, m, &cBinop_WXTO9lDt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4BS2ZfmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_krEdbSd7, HV_BINOP_MULTIPLY, 0, m, &cBinop_krEdbSd7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mW1DGpPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mb4g1Eqy, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mb4g1Eqy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_T8JvQ0hA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a4cIW8U6, HV_BINOP_MULTIPLY, 0, m, &cBinop_a4cIW8U6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j0d5llXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_NOdwA1o9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vgyDcdYg, HV_BINOP_MULTIPLY, 0, m, &cBinop_vgyDcdYg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ShPEfRV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v9XVEjpN, 0, m, &cVar_v9XVEjpN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_h3fZpP8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_92oDiSUv, 0, m, &cVar_92oDiSUv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rttA8yEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_usE4JrlI, 1, m, &cIf_usE4JrlI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RtNMLMcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jFOaJVmt, m);
}

void Heavy_WSTD_3Q::cBinop_nvUGMNR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RtNMLMcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_s5m816Rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_usE4JrlI, 0, m, &cIf_usE4JrlI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_2OE4YqYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zLa2UOOb, HV_BINOP_DIVIDE, 0, m, &cBinop_zLa2UOOb_sendMessage);
}

void Heavy_WSTD_3Q::cVar_DyH8jt41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tc7tWLu5, HV_BINOP_DIVIDE, 1, m, &cBinop_Tc7tWLu5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zLa2UOOb, HV_BINOP_DIVIDE, 1, m, &cBinop_zLa2UOOb_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_rrKblCOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mg7hINB1, HV_BINOP_DIVIDE, 0, m, &cBinop_Mg7hINB1_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_AmYOuTw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mg7hINB1, HV_BINOP_DIVIDE, 1, m, &cBinop_Mg7hINB1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YQCwz2Fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2OE4YqYJ, 0, m, &cVar_2OE4YqYJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iAfkz08V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tc7tWLu5, HV_BINOP_DIVIDE, 0, m, &cBinop_Tc7tWLu5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NnpLPykZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DyH8jt41, 0, m, &cVar_DyH8jt41_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Tc7tWLu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_rrKblCOG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zLa2UOOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_AmYOuTw0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Mg7hINB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_KZarCtHm_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_6XSIhJjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_zYENA4fw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SoUWv0n2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_w7H7WGaS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KZarCtHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SoUWv0n2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_w7H7WGaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_6XSIhJjc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zYENA4fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MceMdrfz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ujdOhKbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUEm8HeQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2dsOwoU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6Yag49oN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUEm8HeQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2dsOwoU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_thbPbLes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUEm8HeQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2dsOwoU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_uQTRf3Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUEm8HeQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2dsOwoU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MceMdrfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RUEm8HeQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_z2dsOwoU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Gx3rSjrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_csXr68E4, 0, m, &cVar_csXr68E4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MxGFZCJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_EsGliujI, 0, m, &cVar_EsGliujI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bJiKbstv, 0, m, &cVar_bJiKbstv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BIplkXEe, 0, m, &cVar_BIplkXEe_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Y9mzQqTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EsGliujI, 0, m, &cVar_EsGliujI_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_mGdEGZXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bJiKbstv, 0, m, &cVar_bJiKbstv_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3xJx7aFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BIplkXEe, 0, m, &cVar_BIplkXEe_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_6P5D2JPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7h9twssz, 0, m, &cVar_7h9twssz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GeRfRBLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lSW6slHG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rfPcgBxL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CWo9ZkBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EcZmCWpU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z4EyZ91I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xn35SpdU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_v5GxKbi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ImA6N8N5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZggPZmM6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rcpzkupx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_6HTpOp3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uOWds7vi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y1nnJvqo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uxYAT05T_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_iuH080zA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sIsnBiuo_sendMessage(_c, 0, m);
  cMsg_DwSeUiLA_sendMessage(_c, 0, m);
  cMsg_niJ3gNpy_sendMessage(_c, 0, m);
  cMsg_IIu1c9vf_sendMessage(_c, 0, m);
  cMsg_BVOUafMs_sendMessage(_c, 0, m);
  cMsg_f5XeLr2O_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RTpqAJTj, 0, m, &cVar_RTpqAJTj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7h9twssz, 0, m, &cVar_7h9twssz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RKe87Zlf, 0, m, &cVar_RKe87Zlf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lJtSPcrN, 0, m, &cVar_lJtSPcrN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_srpxx87d, 0, m, &cVar_srpxx87d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QR45SC4E, 0, m, &cVar_QR45SC4E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Vd9WG7G, 0, m, &cVar_8Vd9WG7G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RVSmOLvU, 0, m, &cVar_RVSmOLvU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N5oUqb6w, 0, m, &cVar_N5oUqb6w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3vKOD2iR, 0, m, &cVar_3vKOD2iR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YeAcDU0F, 0, m, &cVar_YeAcDU0F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2cE6aUHK, 0, m, &cVar_2cE6aUHK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jTs5aq5Y, 0, m, &cVar_jTs5aq5Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6MX8qRbd, 0, m, &cVar_6MX8qRbd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZLAGVN56, 0, m, &cVar_ZLAGVN56_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O3VmYZPK, 0, m, &cVar_O3VmYZPK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h4JHj7nV, 0, m, &cVar_h4JHj7nV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JyVw9mrJ, 0, m, &cVar_JyVw9mrJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_znkDZzX3, 0, m, &cVar_znkDZzX3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gqY4cIii, 0, m, &cVar_gqY4cIii_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EYVuXo4m, 0, m, &cVar_EYVuXo4m_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_okSjXXBl, 0, m, &cVar_okSjXXBl_sendMessage);
  cMsg_MxGFZCJQ_sendMessage(_c, 0, m);
  cMsg_Gx3rSjrn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_KePWGtdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_00v76p5n, HV_BINOP_MULTIPLY, 0, m, &cBinop_00v76p5n_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_BaYL5FQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TdurPOYd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rVbYRZH2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RvaF2k6D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7mqmn5vN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Eu8Yoes3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_a5dWdj0R_sendMessage);
  cMsg_sGPMSFrs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_vRsCdxWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aDz9rBr7, HV_BINOP_MULTIPLY, 0, m, &cBinop_aDz9rBr7_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5FmsqTyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_s57I4r9j_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Y3mlBxeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SA5DWBc1, HV_BINOP_MULTIPLY, 1, m, &cBinop_SA5DWBc1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ww7Cikae_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_D5Rwbf7b_sendMessage);
  cMsg_QOyAL59m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_vqBETnka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IqKigllM, HV_BINOP_MULTIPLY, 0, m, &cBinop_IqKigllM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_jcYUxbe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l8i4xRO0_sendMessage(_c, 0, m);
  cMsg_K91xIFaJ_sendMessage(_c, 0, m);
  cMsg_bVz9OEtW_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_K5GDFJFc_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_60JkJTuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mcvzJ6Lv_sendMessage);
  cMsg_Ntec8pNz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_p6wRPT3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_srpxx87d, 0, m, &cVar_srpxx87d_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kcJmjQsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uwtvks7S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BsfQRBSx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bGG2tuLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dqRlqGOi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NfH6EchX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zL7egbeC_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nfpTs1BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a0DvGzcA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pM2NsgkE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gdb6QAUz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HJWVRqea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LgVxQb4W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3MbClTos_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H3PsYCEC_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fm7zyJh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fNgxj8wy, HV_BINOP_MULTIPLY, 0, m, &cBinop_fNgxj8wy_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GIzjSxFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_j4CSXdCK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ei4ZbXTJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jvSIRPNo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0SUnKlv2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_e93N5RBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nCxva97k_sendMessage);
  cMsg_ueizxBQ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_MEgzHM9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7lt6dfEC, HV_BINOP_MULTIPLY, 0, m, &cBinop_7lt6dfEC_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LUxUMqlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1RifQOWv_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_WLLTvbzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kyezPcXC, HV_BINOP_MULTIPLY, 1, m, &cBinop_kyezPcXC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_X1pRRZGq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Iobg9z4T_sendMessage);
  cMsg_qDZlWAdG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_9J8dxTuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WWg2kNYU, HV_BINOP_MULTIPLY, 0, m, &cBinop_WWg2kNYU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_IPO5pI7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_woKKPJJ9_sendMessage(_c, 0, m);
  cMsg_UP8WVXNk_sendMessage(_c, 0, m);
  cMsg_n6vxQLvf_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3oYly2RX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_4UHmekKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bNUa8mbe_sendMessage);
  cMsg_zwhVIUqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_JV2Tj9Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_csXr68E4, 0, m, &cVar_csXr68E4_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_9To1tawT, VOf(Bf0));
    __hv_line_f(&sLine_JaFdJuzA, VOf(Bf1));
    __hv_line_f(&sLine_cQX4gkTi, VOf(Bf2));
    __hv_line_f(&sLine_I3xmZLEJ, VOf(Bf3));
    __hv_line_f(&sLine_hyyTcs33, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_vMW7mDXX, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_J2aAYIhf, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_jfJXNnet, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_SYbVdvn5, VOf(Bf1));
    __hv_line_f(&sLine_gmjZZDck, VOf(Bf0));
    __hv_line_f(&sLine_IZuce8UZ, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_6Dcb8CgM, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_wHtA0j19, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_1lYcPAhh, VOf(Bf5));
    __hv_line_f(&sLine_F87Uv2ZV, VOf(Bf1));
    __hv_line_f(&sLine_ZrrU4hLz, VOf(Bf2));
    __hv_line_f(&sLine_DrWD2q9A, VOf(Bf4));
    __hv_line_f(&sLine_TzW55BTy, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_uwZmSxW2, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_CeeyiJWK, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_tOw7tOrl, VOf(Bf6));
    __hv_line_f(&sLine_swExL2ol, VOf(Bf2));
    __hv_line_f(&sLine_49kQeaM4, VOf(Bf1));
    __hv_line_f(&sLine_NyTMpHVI, VOf(Bf5));
    __hv_line_f(&sLine_2FsznsLH, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_MPArQZDz, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_Orq0IBFi, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Y6OPGTqB, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_jiK1SahI, VOf(Bf2));
    __hv_line_f(&sLine_UbZyodiV, VOf(Bf6));
    __hv_line_f(&sLine_cMNSNtk7, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_baHuWTjy, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_jFOaJVmt, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_PWGUA13Z, VOf(Bf8));
    __hv_line_f(&sLine_TJSbDrXr, VOf(Bf2));
    __hv_line_f(&sLine_fBMqWHs9, VOf(Bf1));
    __hv_line_f(&sLine_SSmEAjxG, VOf(Bf7));
    __hv_line_f(&sLine_R52th48k, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_A7pP8oqh, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_rc07Dvjq, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
